/**
 * 课程任务接口
 */
export interface LessonTask {
  /** 任务ID */
  id: number;
  /** 课程名称 */
  courseName: string;
  /** 微课名称 */
  microLessonName: string;
  /** 用户ID */
  userId: number;
  /** 进度状态 */
  progressStatus: number;
  /** 脚本开始制作时间（时间戳） */
  scriptCreateTime?: number;
  /** 脚本提交审核时间（时间戳） */
  scriptReviewTime?: number;
  /** 脚本审核通过时间（时间戳） */
  scriptConfirmTime?: number;
  /** 开始视频制作时间（时间戳） */
  videoCreateTime?: number;
  /** 视频审核通过时间（时间戳） */
  videoConfirmTime?: number;
  /** 任务完成时间（时间戳） */
  finishTime?: number;
  /** 建议/反馈信息 */
  advise?: string;
  /** 创建时间（时间戳） */
  createdAt: number;
  /** 更新时间（时间戳） */
  updatedAt: number;
}

export interface LessonTaskPagination {
  content: LessonTask[];
  totalElements: number;
  totalPages: number;
  size: number;
  number: number;
  first: boolean;
  last: boolean;
  empty: boolean;
}

/**
 * NOT_STARTED = 0,      // 脚本制作
  SCRIPT_CREATING = 1,  // 脚本审核
  SCRIPT_REVIEW = 2,    // 脚本审核
  SCRIPT_CONFIRMED = 3, // 视频拍摄与制作
  VIDEO_CREATING = 4,   // 视频确认
  VIDEO_CONFIRMED = 5  // 任务完成
 */
// 进度状态枚举
export enum ProgressStatus {
  NOT_STARTED = 0,      // 脚本制作
  SCRIPT_CREATING = 1,  // 脚本审核
  SCRIPT_REVIEW = 2,    // 脚本审核
  SCRIPT_CONFIRMED = 3, // 视频拍摄与制作
  VIDEO_CREATING = 4,   // 视频确认
  VIDEO_CONFIRMED = 5  // 任务完成
}

export type FileUploadDestination = "qq" | "wechat" | "platform";

/**
 * 创建课程任务请求参数接口
 */
export interface CreateLessonTaskRequest {
  /** 课程名称 */
  courseName: string;
  /** 微课名称 */
  microLessonName: string;
  /** 用户ID */
  userId: number;
  /** 建议信息 */
  advise?: string;
}

/**
 * 更新课程任务请求参数接口
 */
export interface UpdateLessonTaskRequest {
  /** 课程名称 */
  courseName?: string;
  /** 微课名称 */
  microLessonName?: string;
  /** 用户ID */
  userId?: number;
  /** 进度状态 */
  progressStatus?: number;
  /** 脚本开始制作时间 */
  scriptCreateTime?: number;
  /** 脚本提交审核时间 */
  scriptReviewTime?: number;
  /** 脚本审核通过时间 */
  scriptConfirmTime?: number;
  /** 开始视频制作时间 */
  videoCreateTime?: number;
  /** 视频审核通过时间 */
  videoConfirmTime?: number;
  /** 任务完成时间 */
  finishTime?: number;
  /** 建议信息 */
  advise?: string;
}
